@@ -1,7 +1,7 @@
 package Rope;
 
 use 5.006; use strict; use warnings;
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 use Rope::Object;
 my (%META, %PRO);
 our @ISA;
@@ -437,7 +437,7 @@ Rope - Tied objects
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =cut
 
@@ -855,6 +855,12 @@ Rope also includes additional helpers for defining properties with fixed types,
 
 	1;
 
+=head1 CAVEATS
+
+before, around and after hooks will work on any property regardless of configuration unless the value is a code reference, here the property must be readonly (you get this by using the function keyword). This is to prevent unexpected behaviour when trying if you have code which sets the property with a new code ref.
+
+If you have a long running process I would suggest calling ->destroy() directly, i hook into the actual DESTROY method however this may or may not be called if Rope keeps the variable in scope.
+
 =head1 AUTHOR
 
 LNATION, C<< <email at lnation.org> >>
