@@ -49,7 +49,7 @@ sub set_value {
 			for (qw/before around after/) {
 				if ($spec->{$_}) {
 					my $val = $spec->{$_}->($value);
-					if ($val) {
+					if (defined $val) {
 						$value = $val;
 					}
 				}
@@ -116,17 +116,22 @@ sub FETCH {
         my ($self, $key) = @_;
         my $k = $self->{properties}->{$key};
 	return undef unless defined $k->{value};
-	if ((ref($k->{value}) || '') eq 'CODE') {
+	if (!$k->{writeable} && !$k->{configurable} && (ref($k->{value}) || '') eq 'CODE') {
 		if ($k->{before} || $k->{after} || $k->{around}) {
 			return sub {
 				my (@params) = @_;
-				@params = $k->{before}->(@params) if $k->{before};
+				my @new_params;
+				@new_params = $k->{before}->(@params) if $k->{before};
+				@params = @new_params if scalar @new_params;
 				if ($k->{around}) {
 					@params = $k->{around}->($k->{value}, @params);
 				} else {
-					@params = $k->{value}->(@params);
+					@params = $k->{value}->(@params);	
+				}
+				if ($k->{after}) {
+					@new_params = $k->{after}->(@params);
+					@params = @new_params if scalar @new_params;
 				}
-				@params = $k->{after}->(@params) if $k->{after};
 				return wantarray ? @params : $params[0];
 			};
 		}
